@@ -1,4 +1,4 @@
-# Example ~/.config/elinks/hooks.pl
+# Example ~/.elinks/hooks.pl
 #
 # Copyleft by Russ Rowan (See the file "COPYING" for details.)
 #
@@ -26,7 +26,7 @@ use diagnostics;
 
 =head1 CONFIGURATION FILE
 
-This hooks file reads its configuration from I<~/.config/elinks/config.pl>.
+This hooks file reads its configuration from I<~/.elinks/config.pl>.
 The following is an example of the configuration file:
 
 	bork:       yep       # BORKify Google?
@@ -60,7 +60,7 @@ preference value (like I<cnn> for C<weather: CNN>).
 sub loadrc($)
 {
 	my ($preference) = @_;
-	my $configperl = $ENV{'HOME'} . '/.config/elinks/config.pl';
+	my $configperl = $ENV{'HOME'} . '/.elinks/config.pl';
 	my $answer = '';
 
 	open RC, "<$configperl" or return $answer;
@@ -100,7 +100,6 @@ powerful.
 
 =over
 
-=item
 I<Developer's usage>: The function I<goto_url_hook> is called when the hook is
 triggered, taking the target URL and current URL as its two arguments.  It
 returns the final target URL.
@@ -136,7 +135,7 @@ B<bugmenot> or B<bn>
 	{
 		($current_url) = $current_url =~ /^.*:\/\/(.*)/;
 		my $bugmenot = 'http://bugmenot.com/view.php?url=' . $current_url;
-		#my $tempfile = $ENV{'HOME'} . '/.config/elinks/elinks';
+		#my $tempfile = $ENV{'HOME'} . '/.elinks/elinks';
 		#my $matrix = '1234567890ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz';
 		#for (0..int(rand(7) + 9))
 		#{
@@ -186,7 +185,7 @@ B<bugmenot> or B<bn>
 			or open FILE, '</usr/dict/words'
 			or open FILE, '</usr/dict/linux.words'
 			or open FILE, '</usr/share/dict/yawl.list'
-			or open FILE, $ENV{"HOME"} . '/.config/elinks/elinks.words'
+			or open FILE, $ENV{"HOME"} . '/.elinks/elinks.words'
 			or return 'http://google.com/webhp?hl=xx-bork';
 		rand($.) < 1 && ($word = $_) while <FILE>;
 		close FILE;
@@ -1078,7 +1077,6 @@ These hooks effect a URL before ELinks has a chance to load it.
 
 =over
 
-=item
 I<Developer's usage>: The function I<follow_url_hook> is called when the hook
 is triggered, taking the target URL as its only argument.  It returns the final
 target URL.
@@ -1149,7 +1147,6 @@ available.
 
 =over
 
-=item
 I<Developer's usage>: The function I<pre_format_html_hook> is called when the
 hook is triggered, taking the document's URL and the HTML source as its two
 arguments.  It returns the rewritten HTML code.
@@ -1227,8 +1224,8 @@ content-type:text/html.
 	# demoronizer
 #	if ($content_type =~ 'text/html')
 #	{
-#		$html =~ s/Ñ/\&mdash;/g;
-#		$html =~ s/\&#252/ü/g;
+#		$html =~ s//\&mdash;/g;
+#		$html =~ s/\&#252//g;
 #		$html =~ s/\&#039(?!;)/'/g;
 #		$html =~ s/]\n>$//gsm;
 		#$html =~ s/%5B/[/g;
@@ -1255,7 +1252,6 @@ you want to use some anonymizer for access to certain sites.
 
 =over
 
-=item
 I<Developer's usage>: The function I<proxy_for_hook> is called when the hook is
 triggered, taking the target URL as its only argument.  It returns the proxy
 URL, empty string to use no proxy or I<undef> to use the default proxy URL.
@@ -1294,7 +1290,6 @@ stuff.
 
 =over
 
-=item
 I<Developer's usage>: The function I<quit_hook> is called when the hook is
 triggered, taking no arguments nor returning anything.  ('cause, you know, what
 would be the point?)
@@ -1313,7 +1308,7 @@ I<bookmarks.folder_state>.
 
 =cut
 	# collapse XBEL bookmark folders (obsoleted by bookmarks.folder_state)
-	my $bookmarkfile = $ENV{'HOME'} . '/.config/elinks/bookmarks.xbel';
+	my $bookmarkfile = $ENV{'HOME'} . '/.elinks/bookmarks.xbel';
 	if (-f $bookmarkfile and loadrc('collapse') eq 'yes')
 	{
 		open BOOKMARKS, "+<$bookmarkfile";
@@ -1344,7 +1339,7 @@ A few words of wisdom from ELinks the Sage.
 	die if (loadrc('fortune') =~ /^(none|quiet)$/);
 	my $cookiejar = 'elinks.fortune';
 	my $ohwhynot = `ls /usr/share/doc/elinks*/$cookiejar 2>/dev/null`;
-	open COOKIES, $ENV{"HOME"} . '/.config/elinks/' . $cookiejar
+	open COOKIES, $ENV{"HOME"} . '/.elinks/' . $cookiejar
 		or open COOKIES, '/etc/elinks/' . $cookiejar
 		or open COOKIES, '/usr/share/elinks/' . $cookiejar
 		or open COOKIES, $ohwhynot
